@@ -3,7 +3,8 @@ coefplot.default <- function(coefs, sds,
             vertical=TRUE,
             v.axis=TRUE, h.axis=TRUE,
             cex.var=0.8, cex.pts=0.9, col.pts=1,
-            var.las=2, main=NULL, xlab=NULL, ylab=NULL, mar=c(1,3,5.1,2),...)
+            var.las=2, main=NULL, xlab=NULL, ylab=NULL, mar=c(1,3,5.1,2),
+            plot=TRUE, ...)
 {
 
      # collect informations
@@ -32,14 +33,14 @@ coefplot.default <- function(coefs, sds,
     
     # add margin to the axis
     k <- 1/n.x   
-    
-    if (vertical){
+    if(plot){
+      if (vertical){
         mar[2] <- min(min.mar[2], trunc(mar[2] + maxchar/10)) + mar[2] + 0.1
         par(mar=mar)
         plot(c(coefs.l, coefs.h), c(idx+k,idx-k), type="n",                                     
             axes=F, main=main, xlab=xlab, ylab=ylab,...) 
         if (h.axis){                                                  
-#            axis(1)                                
+             axis(1)                                
             axis(3)
         }
         if (v.axis){
@@ -57,28 +58,51 @@ coefplot.default <- function(coefs, sds,
         }
     }
     else{ # horizontal
-        mar[1] <- min(min.mar[1], trunc(mar[1] + maxchar/10)) + mar[1] + 0.1
-        par(mar=mar)
-        plot(c(idx+k,idx-k), c(coefs.l, coefs.h), type="n", axes=F, 
-          main=main, xlab=xlab, ylab=ylab,...)                                                  
-        if (v.axis){
-            axis(2, las=var.las)                                
-            #axis(4, las=var.las)
-        }
-        if (h.axis){
-            axis(1, 1:n.x, varnames[1:n.x], las=var.las, tck=FALSE, 
-                lty=0, cex.axis=cex.var) 
-        }
-        abline(h=0, lty=2)                                                 
-        points(idx, coefs, pch=19, cex=cex.pts, col=col.pts)
-        if (CI==2){
-            segments (idx, coefs+sds, idx, coefs-sds, lwd=2, col=col.pts)     
-            segments (idx, coefs+2*sds, idx, coefs-2*sds, lwd=1, col=col.pts)
-        }
-        else if (CI==1) {
-            segments (idx, coefs+sds, idx, coefs-sds, lwd=1, col=col.pts)     
-        }
+      mar[1] <- min(min.mar[1], trunc(mar[1] + maxchar/10)) + mar[1] + 0.1
+      par(mar=mar)
+      plot(c(idx+k,idx-k), c(coefs.l, coefs.h), type="n", axes=F, 
+        main=main, xlab=xlab, ylab=ylab,...)                                                  
+      if (v.axis){
+          axis(2, las=var.las)                                
+          #axis(4, las=var.las)
+      }
+      if (h.axis){
+          axis(1, 1:n.x, varnames[1:n.x], las=var.las, tck=FALSE, 
+              lty=0, cex.axis=cex.var) 
+      }
+      abline(h=0, lty=2)                                                 
+      points(idx, coefs, pch=19, cex=cex.pts, col=col.pts)
+      if (CI==2){
+          segments (idx, coefs+sds, idx, coefs-sds, lwd=2, col=col.pts)     
+          segments (idx, coefs+2*sds, idx, coefs-2*sds, lwd=1, col=col.pts)
+      }
+      else if (CI==1) {
+          segments (idx, coefs+sds, idx, coefs-sds, lwd=1, col=col.pts)     
+      }
     }   
+  }
+  else{
+    if (vertical){
+      mar[2] <- min(min.mar[2], trunc(mar[2] + maxchar/10)) + mar[2] + 0.1
+      par(mar=mar)
+      plot(c(coefs.l, coefs.h), c(idx+k,idx-k), type="n",                                     
+          axes=F, main=main, xlab=xlab, ylab=ylab,...) 
+      if (v.axis){
+          axis(2, n.x:1, varnames[n.x:1], las=var.las, tck=FALSE, 
+              lty=0, cex.axis=cex.var) 
+      }
+    }
+    else{ # horizontal
+      mar[1] <- min(min.mar[1], trunc(mar[1] + maxchar/10)) + mar[1] + 0.1
+      par(mar=mar)
+      plot(c(idx+k,idx-k), c(coefs.l, coefs.h), type="n", axes=F, 
+        main=main, xlab=xlab, ylab=ylab,...)                                                  
+      if (h.axis){
+          axis(1, 1:n.x, varnames[1:n.x], las=var.las, tck=FALSE, 
+              lty=0, cex.axis=cex.var) 
+      }
+    }
+  }   
 }
 
 setMethod("coefplot", signature(object = "numeric"),
